# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-17 23:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('google_address', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='AddressComponent',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('long_name', models.CharField(max_length=400)),
                ('short_name', models.CharField(max_length=400)),
            ],
        ),
        migrations.CreateModel(
            name='AddressComponentType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name='GoogleAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('typed_address', models.CharField(blank=True, max_length=400, null=True)),
                ('typed_address2', models.CharField(blank=True, max_length=400, null=True)),
                ('address_line', models.CharField(blank=True, max_length=400, null=True)),
                ('city_state', models.CharField(blank=True, max_length=400, null=True)),
                ('lat', models.FloatField(blank=True, null=True, verbose_name='lat')),
                ('lng', models.FloatField(blank=True, null=True, verbose_name='lng')),
                ('address_components', models.ManyToManyField(to='google_address.AddressComponent')),
            ],
        ),
        migrations.CreateModel(
            name='GoogleRegion',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('region_name', models.CharField(max_length=400)),
                ('filter_by', models.CharField(max_length=400)),
            ],
        ),
        migrations.AddField(
            model_name='addresscomponent',
            name='types',
            field=models.ManyToManyField(to='google_address.AddressComponentType'),
        ),
    ]
