# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-17 23:56
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('google_address', '0002_auto_20170417_2307'),
    ]

    operations = [
        migrations.RenameField(
            model_name='googleaddress',
            old_name='typed_address',
            new_name='raw',
        ),
    ]
