# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-18 23:04
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('google_address', '0004_auto_20170418_0133'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='GoogleAddress',
            new_name='Address',
        ),
    ]
